@@ -38,13 +38,15 @@ typedef enum BacappPresentValueType {
     BACAPP_PRESENT_VALUE_CHARACTER_STRING,
     BACAPP_PRESENT_VALUE_BIT_STRING,
     BACAPP_PRESENT_VALUE_ENUM,
+    BACAPP_PRESENT_VALUE_DATE,
+    BACAPP_PRESENT_VALUE_TIME,
     BACAPP_PRESENT_VALUE_OBJECT_IDENTIFIER
 } BacappPresentValueType;
 
 #endif /* __PACKET_BACNET_H__ */
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
